import { Story, Canvas, Meta, Description } from "@storybook/addon-docs/blocks";
import { withKnobs, boolean } from "@storybook/addon-knobs";
import { html } from "lit-html";
import CATEGORIES from "../categories";
import readme from "../../dist/docs/components/icon/readme.md";
import availableIcons from "../../src/components/icon/availableIcons.ts";

<Meta title={CATEGORIES.COMPONENTS + "Icon"} />

# Icon

This inserts an SVG icon. The SVG is loaded and cached as needed. The icon is inserted into the DOM as inline SVG.

<Canvas
    mdxSource={`
    <ui-icon name="documents"></ui-icon>
`}
>
    <Story
        height="20px"
        name="Icon"
        parameters={{ jest: ["icon.e2e.ts", "validate.spec.ts"] }}
    >
        {html` <ui-icon name="documents"></ui-icon> `}
    </Story>
</Canvas>

### Styling icons

The SVG can be styled via CSS: The size of the icon can be changed by setting the `font-size` for the `<ui-icon>` element or its parent. The color can be changed by using SVG styling like `fill` or `stroke`.

<Canvas
    mdxSource={`
    <span style="font-size: 25px; fill: #ff1e00">
        <ui-icon name="documents"></ui-icon>
    </span>
`}
>
    <Story height="40px" name="Styled Icon">
        {html`<span style="font-size: 25px; fill: #ff1e00"
            ><ui-icon name="documents"></ui-icon
        ></span>`}
    </Story>
</Canvas>

## All available Icons

<Story name="all available Icons">
    {html`
        <table style="margin-left: 0">
            ${availableIcons.map(
                (name) => html`
                    <tr>
                        <td>${name}</td>
                        <td style="font-size:30px">
                            <ui-icon name="${name}"></ui-icon>
                        </td>
                    </tr>
                `
            )}
        </table>
    `}
</Story>

# Developer Documentation

<Description markdown={readme} />

## Adding more icons

To add a new icon, place the SVG in `src/components/icon/assets` and add the name of the new file (without .svg) in `src/components/icon/availableIcons.ts`
